<?php

/**
 * Class mwcf (Multi Website Cache Flush)
 *
 * This class encapsulates some logic for the multiple website caching, which
 * are called by the functions that are set in mwcf_menu().
 */
class mwcf {

  /**
   * Initializes the config class members via the mwcf config file.
   */
  function __construct() {
    // Values will be filled from mwcf.conf.php.
    $aUrls                   = '';
    $bRenewCacheByDomainCall = '';
    $sCacheClearKey          = '';

    $files_dir = variable_get('file_public_path', conf_path() . '/files');
    include_once($files_dir . '/mwcf.conf.php');

    $this->aUrls                   = $aUrls;
    $this->bRenewCacheByDomainCall = $bRenewCacheByDomainCall;
    $this->sCacheClearKey          = $sCacheClearKey;
  }

  /**
   * This function clears all caches at all sites.
   *
   * @return null
   */
  public function clear_cache_everywhere() {
    $aUrlsForCacheClear = array();

    foreach ($this->aUrls as $url) {
      watchdog('info', 'Multi Website Cache Flush: Initialized cache clear ' .
        'on the following Drupal Website URL: ' . $url);
      $aUrlsForCacheClear[] = $url . '/ccall?cache_clear_key='
        . $this->sCacheClearKey;
    }

    new ParallelGet($aUrlsForCacheClear);

    if ($this->bRenewCacheByDomainCall === 1) {
      $this->renew_cache_by_domain_call();
    }

  }

  /**
   * This function initializes a simple cache rebuild by calling the specified
   * domains. To use this functionality, the $bRenewCacheByDomainCall-variable
   * needs be set to "1" in the config file.
   *
   * @return null
   */
  protected function renew_cache_by_domain_call() {
    $aDomainsToVisit = array();

    foreach ($this->aUrls as $url) {
      watchdog('info', 'Multi Website Cache Flush: Visited the following' .
        ' Domain for simple cache re-build: ' . $url);
      $aDomainsToVisit[] = $url;
    }

    new ParallelGet($aDomainsToVisit);
  }

  /**
   * This function clears the entire cache on the current site. It can be
   * called via appropriate cache clear key as get parameter or if the logged
   * in user has the appropriate permission.
   *
   * @return null
   */
  public function clear_all_caches() {
    if ((isset($_GET['cache_clear_key']) &&
      $this->sCacheClearKey == $_GET['cache_clear_key']) OR
      user_access('access url to flush entire cache on single site')
    ) {
      drupal_flush_all_caches();
      watchdog('info', 'Multi Website Cache Flush: Cleared all caches.');
    }
    else {
      watchdog('error', 'Multi Website Cache Flush: Wrong cache key' .
        ' or permission. Caches could not be flushed.');
    }

    if (user_access('access url to flush entire cache on single site')) {
      echo 'Multi Website Cache Flush: Entire single site cache flushed.';
    } else {
      echo 'Multi Website Cache Flush: Error - no sufficient permission.';
    }
  }

}
